#' @export
FIESTAutils::savedata_options

#' @export
FIESTAutils::unit_options

#' @export
FIESTAutils::table_options

#' @export
FIESTAutils::title_options

#' @export
FIESTAutils::strata_options

#' @export
FIESTAutils::multest_options

#' @export
FIESTAutils::spMakeSpatial_options

#' @export
FIESTAutils::datExportData

#' @export
FIESTAutils::popFilters

#' @export
FIESTAutils::popTables

#' @export
FIESTAutils::popTableIDs

#' @export
FIESTAutils::tableIDs

#' @export
FIESTAutils::database_options

#' @export
FIESTAutils::datSum_options


#' @export
FIESTAutils::DBcreateSQLite

#' @export
FIESTAutils::DBtestPostgreSQL

#' @export
FIESTAutils::DBtestSQLite

#' @export
FIESTAutils::eval_options

#' @export
FIESTAutils::xy_options

#' @inherit FIESTAutils::GDT_NAMES source title
#' @export
GDT_NAMES <- FIESTAutils::GDT_NAMES

#' @inherit FIESTAutils::kindcd3old source title
#' @export
kindcd3old <- FIESTAutils::kindcd3old

#' @inherit FIESTAutils::ref_codes references source title
#' @export
ref_codes <- FIESTAutils::ref_codes

#' @inherit FIESTAutils::ref_diacl2in references source title
#' @export
ref_diacl2in <- FIESTAutils::ref_diacl2in

#' @inherit FIESTAutils::ref_domain source title
#' @export
ref_domain <- FIESTAutils::ref_domain

#' @inherit FIESTAutils::ref_estvar source title
#' @export
ref_estvar <- FIESTAutils::ref_estvar

#' @inherit FIESTAutils::ref_units source title
#' @export
ref_units <- FIESTAutils::ref_units

#' @inherit FIESTAutils::ref_statecd references source title
#' @export
ref_statecd <- FIESTAutils::ref_statecd

#' @inherit FIESTAutils::stunitco source title
#' @export
stunitco <- FIESTAutils::stunitco

#' @inherit FIESTAutils::ref_plt source title
#' @export
ref_plt <- FIESTAutils::ref_plt

#' @inherit FIESTAutils::ref_cond source title
#' @export
ref_cond <- FIESTAutils::ref_cond

#' @inherit FIESTAutils::ref_tree source title
#' @export
ref_tree <- FIESTAutils::ref_tree

#' @inherit FIESTAutils::ref_shp source title
#' @export
ref_shp <- FIESTAutils::ref_shp

#' @inherit FIESTAutils::ref_species source title
#' @export
ref_species <- FIESTAutils::ref_species

#' @inherit FIESTAutils::ref_conversion source title
#' @export
ref_conversion <- FIESTAutils::ref_conversion

#' @inherit FIESTAutils::ref_popType source title
#' @export
ref_popType <- FIESTAutils::ref_popType

#' @inherit FIESTAutils::ref_titles source title
#' @export
ref_titles <- FIESTAutils::ref_titles



